@@ -23,6 +23,6 @@ class UserAgentMiddleware(SelectedBackend):
         self.USER_AGENT_REGEX = re.compile(regex_str, re.IGNORECASE)
 
     def process_request(self, request):
-        if self.USER_AGENT_REGEX.match(request.META["HTTP_USER_AGENT"]):
+        if "HTTP_USER_AGENT" in request.META and self.USER_AGENT_REGEX.match(request.META["HTTP_USER_AGENT"]):
             url = request.build_absolute_uri()
             return HttpResponse(self.backend.get_rendered_page(url))
